@@ -1,42 +1,52 @@
-;; Constants
+; Constants
 (integer) @number
 
-;; Variables and Symbols
+; Variables and Symbols
+(typed_binding
+  (atom
+    (qid) @variable))
 
-(typed_binding (atom (qid) @variable))
 (untyped_binding) @variable
-(typed_binding (expr) @type)
+
+(typed_binding
+  (expr) @type)
 
 (id) @function
+
 (bid) @function
 
-(function_name (atom (qid) @function))
+(function_name
+  (atom
+    (qid) @function))
+
 (field_name) @function
 
-
-[(data_name) (record_name)] @constructor
+[
+  (data_name)
+  (record_name)
+] @constructor
 
 ; Set
 (SetN) @type.builtin
 
-(expr . (atom) @function)
+(expr
+  .
+  (atom) @function)
 
 ((atom) @boolean
   (#any-of? @boolean "true" "false" "True" "False"))
 
-;; Imports and Module Declarations
-
-"import"  @include
+; Imports and Module Declarations
+"import" @include
 
 (module_name) @namespace
 
-;; Pragmas and comments
-
+; Pragmas and comments
 (pragma) @preproc
 
 (comment) @comment
 
-;; Keywords
+; Keywords
 [
   "where"
   "data"
@@ -61,20 +71,16 @@
   "infixl"
   "infixr"
   "record"
-]
-@keyword
-
-;;;(expr 
-;;;	f_name: (atom) @function)
-;; Brackets
+] @keyword
 
+;(expr
+;	f_name: (atom) @function)
+; Brackets
 [
   "("
   ")"
   "{"
-  "}"]
-@punctuation.bracket
+  "}"
+] @punctuation.bracket
 
-[
-  "="
-] @operator
+"=" @operator
