@@ -1,32 +1,50 @@
 (comment) @comment
+
 (generated_comment) @comment
+
 (title) @text.title
+
 (text) @text
+
 (branch) @text.reference
+
 (change) @keyword
+
 (filepath) @text.uri
+
 (arrow) @punctuation.delimiter
 
 (subject) @text.title
-(subject (overflow) @text)
-(prefix (type) @keyword)
-(prefix (scope) @parameter)
-(prefix [
+
+(prefix
+  (type) @keyword)
+
+(prefix
+  (scope) @parameter)
+
+(prefix
+  [
     "("
     ")"
     ":"
-] @punctuation.delimiter)
-(prefix [
-    "!"
-] @punctuation.special)
+  ] @punctuation.delimiter)
+
+(prefix
+  "!" @punctuation.special)
 
 (message) @text
 
-(trailer (token) @keyword)
-(trailer (value) @text)
+(trailer
+  (token) @keyword)
 
-(breaking_change (token) @text.warning)
-(breaking_change (value) @text)
+(trailer
+  (value) @text)
+
+(breaking_change
+  (token) @text.warning)
+
+(breaking_change
+  (value) @text)
 
 (scissor) @comment
 
